@@ -20,7 +20,7 @@ def download_and_unzip(url, extract_to='.'):
 
 
 def load():
-    url = 'https://drive.google.com/u/0/uc?id=1Q1e1ovKOn_5jzO7k1E_P8ikTIdW7DhhQ&export=download'
+    url = 'https://drive.google.com/u/0/uc?id=19xIQPABFRfV8veUC3anXIBxBbUEeA37D&export=download'
     download_and_unzip(url, extract_to='.')
 
 
